### Name: as.layer
### Title: Overlay panels with different scales
### Aliases: as.layer as.layer.trellis
### Keywords: aplot

### ** Examples

set.seed(1)
foo <- list(x = as.Date(1:100, "2000-01-01"),
            y = cumsum(rnorm(100)))
obj1 <- xyplot(y ~ x, foo, type = "l",
  scales = list(format = "%Y %b"))
obj2 <- xyplot(jitter(y, amount = 3) ~ I(x + 360), foo,
  type = "l", scales = list(format = "%Y %b"))

## simple case: no axes for the overlaid plot
obj1 + as.layer(obj2, style = 2, axes = NULL)

## draw x axis inside (opposite); remove original ticks from top
update(obj1, scales = list(tck = c(1,0))) +
    as.layer(obj2, style = 2, axes = "x")

## draw original axis in that series' style color
col1 <- trellis.par.get("superpose.line")$col[1]
obj1 <- update(obj1, scales = list(tck = c(1,0),
    x = list(col = col1, col.line = col1) ))

## draw x axis outside (opposite); need extra space
update(obj1, lattice.options = list(layout.heights =
    list(top.padding = list(x = 2)))) +
  as.layer(obj2, style = 2, axes = "x", outside = TRUE)

## or draw both series as layers, over a blank "dummy" plot
xAxPad <- list(layout.heights = list(
    axis.bottom = list(x = 2.5, units = "char"),
    axis.top = list(x = 2.5, units = "char")))
dummy <- update(obj1, panel = function(...) NULL,
    scales = list(x = list(draw = FALSE)),
    lattice.options = xAxPad)
dummy +
  as.layer(obj1, style = 1, axes = "x", out = TRUE, opp = FALSE) +
  as.layer(obj2, style = 2, axes = "x", out = TRUE)

## applying one panel layer to several panels of another object
xyplot(Sepal.Length + Sepal.Width ~ Petal.Length + Petal.Width | Species,
       data = iris, scales = "free") +
   as.layer(levelplot(volcano), under = TRUE)



